# JassBot

## Useful commands
Start tensorboard:
    
    tensorboard --logdir log
    
SSH to remote machine with port forwarding for viewing the tensorboard
    
    ssh -L 6006:127.0.0.1:6006 -i ~/.ssh/diufpc29 joel@diufpc29